==> plain-credentials-1.2-sources.jar: org/jenkinsci/plugins/plaincredentials/impl/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.plaincredentials.impl;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code FileCredentialsImpl.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static String FileCredentialsImpl_secret_file() {
        return holder.format("FileCredentialsImpl.secret_file");
    }

    /**
     * Key {@code FileCredentialsImpl.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static Localizable _FileCredentialsImpl_secret_file() {
        return new Localizable(holder, "FileCredentialsImpl.secret_file");
    }

    /**
     * Key {@code StringCredentialsImpl.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static String StringCredentialsImpl_secret_text() {
        return holder.format("StringCredentialsImpl.secret_text");
    }

    /**
     * Key {@code StringCredentialsImpl.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static Localizable _StringCredentialsImpl_secret_text() {
        return new Localizable(holder, "StringCredentialsImpl.secret_text");
    }

}

==> plain-credentials-1.8-sources.jar: org/jenkinsci/plugins/plaincredentials/impl/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.plaincredentials.impl;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code FileCredentialsImpl.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static String FileCredentialsImpl_secret_file() {
        return holder.format("FileCredentialsImpl.secret_file");
    }

    /**
     * Key {@code FileCredentialsImpl.secret_file}: {@code Secret file}.
     * 
     * @return
     *     {@code Secret file}
     */
    public static Localizable _FileCredentialsImpl_secret_file() {
        return new Localizable(holder, "FileCredentialsImpl.secret_file");
    }

    /**
     * Key {@code StringCredentialsImpl.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static String StringCredentialsImpl_secret_text() {
        return holder.format("StringCredentialsImpl.secret_text");
    }

    /**
     * Key {@code StringCredentialsImpl.secret_text}: {@code Secret text}.
     * 
     * @return
     *     {@code Secret text}
     */
    public static Localizable _StringCredentialsImpl_secret_text() {
        return new Localizable(holder, "StringCredentialsImpl.secret_text");
    }

}
